@@ -72,20 +72,6 @@ class CVexchangeTraderApi:
         self._client_ref = str(uuid.uuid4())
         # 设置策略ID
         self._sender_user = None
-        # self._logger = AztLog(filename=logfile)
-
-    # def log(self, *msgs):
-    #     self._logger.log(*msgs)
-
-    # def RegisterSpi(self, azt_spi):
-    #     """
-    #     注册spi
-    #     :param azt_spi: 回调类,可以直接将类传入,也可以传入类实例
-    #     """
-    #     if azt_spi.__class__ is ABCMeta:
-    #         azt_spi = azt_spi()
-    #     self.spi = azt_spi
-    #     self.spi.api = self
 
     def _queue_subscribe(self, spi_name):
         self._queue_map[spi_name] = queue.Queue()
@@ -102,21 +88,21 @@ class CVexchangeTraderApi:
         if spi_name in self._queue_map:
             self._queue_map.pop(spi_name)
 
-    def Init(self, server_addr: str, spi=None, log_file=None, **kwargs):
-        # 设置日志
-        if log_file is not None:
-            # azt_logger.log("已设置日志输出：", log_file)
-            azt_logger._logger.set_log2file(log_file)
-
-        # 设置日志级别
-        if kwargs.get("log_debug", False):
-            azt_logger.log_debug()
-        if kwargs.get("log_info", False):
-            azt_logger.log_info()
-        if kwargs.get("log_warning", False):
-            azt_logger.log_warning()
-        if kwargs.get("log_error", False):
-            azt_logger.log_error()
+    def Init(self, server_addr: str, spi=None):
+        # # 设置日志
+        # if log_file is not None:
+        #     # azt_logger.log("已设置日志输出：", log_file)
+        #     azt_logger._logger.set_log2file(log_file)
+        #
+        # # 设置日志级别
+        # if kwargs.get("log_debug", False):
+        #     azt_logger.log_debug()
+        # if kwargs.get("log_info", False):
+        #     azt_logger.log_info()
+        # if kwargs.get("log_warning", False):
+        #     azt_logger.log_warning()
+        # if kwargs.get("log_error", False):
+        #     azt_logger.log_error()
 
         # 设置服务器地址
         if not server_addr.startswith("tcp"):
@@ -171,6 +157,7 @@ class CVexchangeTraderApi:
 
     def __report_handel(self, unit_msg):
         # print(f"收到消息：{ unit_msg.msg_type}-{unit_msg.msg_id}")
+        azt_logger.debug(f"收到消息：{unit_msg.msg_type}-{unit_msg.msg_id}")
         if unit_msg.msg_type != MsgTypeProto.KMsgType_Exchange_Rsp:
             return
         "-----------"
@@ -178,7 +165,7 @@ class CVexchangeTraderApi:
         if unit_msg.msg_id == EnumProto.KVexchangeMsgID_RegisterAck:
             msg = MsgProto.RegisterAck()
             unit_msg.msg_body.Unpack(msg)
-            azt_logger.debug(msg)
+            # azt_logger.debug(msg)
             cbmsg = spi_struct.RegisterAck.__proto2py__(msg)
             self.spi.onRegisterReq(cbmsg)
             if "onRegisterReq" in self._queue_map:
@@ -188,7 +175,7 @@ class CVexchangeTraderApi:
             self._logined = True
             msg = MsgProto.LoginAck()
             unit_msg.msg_body.Unpack(msg)
-            azt_logger.debug(msg)
+            # azt_logger.debug(msg)
             cbmsg = spi_struct.LoginAck.__proto2py__(msg)
             self.spi.onUserLoginReq(cbmsg)
             if "onUserLoginReq" in self._queue_map:
@@ -197,7 +184,7 @@ class CVexchangeTraderApi:
         elif unit_msg.msg_id == EnumProto.KVexchangeMsgID_UserInfoQryAck:
             msg = MsgProto.UserRegisterInfo()
             unit_msg.msg_body.Unpack(msg)
-            azt_logger.debug(msg)
+            # azt_logger.debug(msg)
             cbmsg = spi_struct.UserRegisterInfo.__proto2py__(msg)
             self.spi.onUserInfoQryReq(cbmsg)
             if "onUserInfoQryReq" in self._queue_map:
@@ -206,7 +193,7 @@ class CVexchangeTraderApi:
         elif unit_msg.msg_id == EnumProto.KTradeReqType_AccDepositAck:
             msg = MsgProto.AccDepositAck()
             unit_msg.msg_body.Unpack(msg)
-            azt_logger.debug(msg)
+            # azt_logger.debug(msg)
             cbmsg = spi_struct.AccDepositAck.__proto2py__(msg)
             self.spi.onAccDepositReq(cbmsg)
             if "onAccDepositReq" in self._queue_map:
@@ -215,7 +202,7 @@ class CVexchangeTraderApi:
         elif unit_msg.msg_id == EnumProto.KTradeReqType_TradingAccQryAck:
             msg = MsgProto.AccMargin()
             unit_msg.msg_body.Unpack(msg)
-            azt_logger.debug(msg)
+            # azt_logger.debug(msg)
             cbmsg = spi_struct.AccMargin.__proto2py__(msg)
             self.spi.onTradingAccQryReq(cbmsg)
             if "onTradingAccQryReq" in self._queue_map:
@@ -233,7 +220,7 @@ class CVexchangeTraderApi:
         elif unit_msg.msg_id == EnumProto.KQueryTradesAck:
             msg = MsgProto.QueryTradesAck()
             unit_msg.msg_body.Unpack(msg)
-            azt_logger.debug(msg)
+            # azt_logger.debug(msg)
             cbmsg = spi_struct.QueryTradesAck.__proto2py__(msg)
             self.spi.onQueryTradesReq(cbmsg)
             if "onQueryTradesReq" in self._queue_map:
@@ -242,7 +229,7 @@ class CVexchangeTraderApi:
         elif unit_msg.msg_id == EnumProto.KQueryPositionsAck:
             msg = MsgProto.QueryPositionsAck()
             unit_msg.msg_body.Unpack(msg)
-            azt_logger.debug(msg)
+            # azt_logger.debug(msg)
             cbmsg = spi_struct.QueryPositionsAck.__proto2py__(msg)
             self.spi.onQueryPositionsReq(cbmsg)
             if "onQueryPositionsReq" in self._queue_map:
@@ -260,7 +247,7 @@ class CVexchangeTraderApi:
         elif unit_msg.msg_id == EnumProto.KQueryHistoryTradesAck:
             msg = MsgProto.QueryPositionsAck()
             unit_msg.msg_body.Unpack(msg)
-            azt_logger.debug(msg)
+            # azt_logger.debug(msg)
             cbmsg = spi_struct.QueryPositionsAck.__proto2py__(msg)
             self.spi.onQueryHistoryTradesReq(cbmsg)
             if "onQueryHistoryTradesReq" in self._queue_map:
@@ -270,19 +257,19 @@ class CVexchangeTraderApi:
         elif unit_msg.msg_id == EnumProto.KTradeRspType_OrdStatusReport:
             msg = MsgProto.OrdReport()
             unit_msg.msg_body.Unpack(msg)
-            azt_logger.debug(msg)
+            # azt_logger.debug(msg)
             self.spi.onOrderReport(spi_struct.OrdReport.__proto2py__(msg))
 
         elif unit_msg.msg_id == EnumProto.KTradeReqType_ExecReport:
             msg = MsgProto.TradeReport()
             unit_msg.msg_body.Unpack(msg)
-            azt_logger.debug(msg)
+            # azt_logger.debug(msg)
             self.spi.onTradeReport(spi_struct.TradeReport.__proto2py__(msg))
 
         elif unit_msg.msg_id == EnumProto.KTradeReqType_RejectCancelReport:
             msg = MsgProto.CancelOrderReject()
             unit_msg.msg_body.Unpack(msg)
-            azt_logger.debug(msg)
+            # azt_logger.debug(msg)
             self.spi.onCancelOrderReject(spi_struct.CancelOrderReject.__proto2py__(msg))
         else:
             azt_logger.warning("Unkown recv msg msg_id!")
